@@ -285,6 +285,9 @@ class Form(SecuredController):
         params.editable = True
         params.view_type = 'form'
         
+        if kw.get('default_date'):
+            params.context.update({'default_date' : kw.get('default_date')})
+            
         cherrypy.request._terp_view_target = kw.get('target')
 
         if params.view_mode and 'form' not in params.view_mode:
@@ -390,7 +393,9 @@ class Form(SecuredController):
             proxy = rpc.RPCProxy(params.model)
 
             if not params.id:
-                id = proxy.create(data, params.context)
+                ctx = params.context or {}
+                ctx.update(rpc.session.context.copy())
+                id = proxy.create(data, ctx)
                 params.ids = (params.ids or []) + [int(id)]
                 params.id = int(id)
                 params.count += 1
@@ -417,6 +422,31 @@ class Form(SecuredController):
         if terp_save_only:
             return dict(params=params, data=data)
 
+
+        def get_params(p, f):
+
+            pp = p.chain_get(f)
+            px = rpc.RPCProxy(p.model)
+
+            _ids = pp.ids
+            _all = px.read([p.id], [f])[0][f]
+            _new = [i for i in _all if i not in _ids]
+
+            pp.ids = _all
+            if _new:
+                pp.id = _new[0]
+
+            return pp
+
+        if params.source and len(params.source.split("/")) > 1:
+
+            path = params.source.split("/")
+            p = params
+            for f in path:
+                p = get_params(p, f)
+
+            return self.create(params)
+
         args = {'model': params.model,
                 'id': params.id,
                 'ids': ustr(params.ids),
@@ -451,6 +481,10 @@ class Form(SecuredController):
         id = (id or False) and int(id)
         ids = (id or []) and [id]
 
+        ctx = (params.context or {}).copy()
+        ctx.update(rpc.session.context.copy())
+        ctx.update(button.context or {})
+
         if btype == 'cancel':
             if name:
                 button.btype = "object"
@@ -485,13 +519,30 @@ class Form(SecuredController):
                 return actions.execute(res, ids=[id])
 
         elif btype == 'object':
-            ctx = params.context or {}
-            ctx.update(rpc.session.context.copy())
             res = rpc.session.execute('object', 'execute', model, name, ids, ctx)
 
             if isinstance(res, dict):
                 from openerp.controllers import actions
-                return actions.execute(res, ids=[id])
+                result = actions.execute(res, ids=[id])
+                
+                if result is None or type(result) == type({}):
+                    return """<html>
+                                <head>
+                                    <script type="text/javascript">
+                                        window.onload = function(evt){
+                                            if (window.opener) {
+                                                window.opener.setTimeout("window.location.reload()", 0);
+                                                window.close();
+                                            } else {
+                                                window.location.href = '/';
+                                            }
+                                        }
+                                    </script>
+                                </head>
+                                <body></body>
+                            </html>"""
+                else:
+                    return result
 
         elif btype == 'action':
             from openerp.controllers import actions
@@ -505,7 +556,7 @@ class Form(SecuredController):
 
             res = actions.execute_by_id(action_id, type=action_type,
                                         model=model, id=id, ids=ids,
-                                        context=params.context or {})
+                                        context=ctx or {})
             if res:
                 return res
 
@@ -663,6 +714,9 @@ class Form(SecuredController):
                 o += l
             elif id in ids:
                 id = ids[ids.index(id)+1]
+            elif id == False:
+                o = 0
+                id = ids[0]
 
         if filter_action:
             # remember the current page (tab) of notebooks
@@ -674,8 +728,10 @@ class Form(SecuredController):
             if params.search_domain is not None:
                 domain = params.search_domain
                 data = params.search_data
-
-            res = search(params.model, o, l, domain=domain, data=data)
+            
+            ctx = params.context or {}
+            ctx.update(rpc.session.context.copy())            
+            res = search(params.model, o, l, domain=domain, context=ctx, data=data)
 
             o = res['offset']
             l = res['limit']
@@ -823,7 +879,7 @@ class Form(SecuredController):
         model = params.model
 
         id = params.id or False
-        ids = params.ids or []
+        ids = params.selection or params.ids or []
 
         if params.view_type == 'form':
             #TODO: save current record
@@ -850,27 +906,30 @@ class Form(SecuredController):
         
         id = params.id or False
         ids = params.selection or []
-        
+        context = params.context or {}
+        action = {}
+
+        if data.get('datas'):
+            action = eval(data.get('datas'))
+        type = action.get('type')
+        act_id = params.action
+
         if not ids and id:
             ids = [id]
-            
+
         if not id and ids:
             id = ids[0]
-        
+
         domain = params.domain or []
-        context = params.context or {}
-        
-        act_id = params.action
-        
         if not params.selection and not params.id:
             raise common.message(_('You must save this record to use the sidebar button!'))
         
         if not act_id:
             return self.do_action('client_action_multi', datas=kw)
-        
-        action_type = rpc.RPCProxy('ir.actions.actions').read(act_id, ['type'], rpc.session.context)['type']
-        action = rpc.session.execute('object', 'execute', action_type, 'read', act_id, False, rpc.session.context)
-        
+        if type is None:
+            action_type = rpc.RPCProxy('ir.actions.actions').read(act_id, ['type'], rpc.session.context)['type']
+            action = rpc.session.execute('object', 'execute', action_type, 'read', act_id, False, rpc.session.context)
+
         action['domain'] = domain or []
         action['context'] = context or {}
         
@@ -884,7 +943,7 @@ class Form(SecuredController):
 
         return self.create(current)
 
-    @expose('json')
+    @expose('json', methods=('POST',))
     def on_change(self, **kw):
 
         data = kw.copy()
@@ -958,14 +1017,24 @@ class Form(SecuredController):
         # apply validators (transform values from python)
         values = result['value']
         values2 = {}
+        
         for k, v in values.items():
             key = ((prefix or '') and prefix + '/') + k
-
+            kind = ''
+            if data.get(key):
+                kind =  data[key].get('type')
+            
             if key in data and key != 'id':
                 values2[k] = data[key]
                 values2[k]['value'] = v
             else:
                 values2[k] = {'value': v}
+            
+            if kind == 'float':
+                field = proxy.fields_get([k], ctx2)
+                digit = field[k].get('digits')
+                if digit: digit = digit[1]
+                values2[k]['digit'] = digit or 2
 
         values = TinyForm(**values2).from_python().make_plain()
 
@@ -978,8 +1047,8 @@ class Form(SecuredController):
                 values[k] = [values[k], tw.many2one.get_name(relation, values[k])]
 
             if kind == 'picture':
-                values[k] = generate_url_for_picture(model, k, ctx.id, values[k])
-
+                values[k] = generate_url_for_picture(model, k, ctx.id, values[k])                
+                
         result['value'] = values
 
         # convert domains in string to prevent them being converted in JSON
@@ -1031,7 +1100,7 @@ class Form(SecuredController):
 
     def reset_notebooks(self):
         for name in cherrypy.request.cookie.keys():
-            if name.endswith('_notebookTGTabber'):
+            if name.endswith('TGTabber'):
                 cherrypy.response.cookie[name] = 0
 
     @expose('json')
