@@ -32,6 +32,7 @@ import time
 import types
 import base64
 import xml.dom.minidom
+import re
 
 import csv
 import StringIO
@@ -50,8 +51,10 @@ from openerp.utils import TinyDict
 
 import openerp.widgets as tw
 
-def datas_read(ids, model, fields):
-    return rpc.RPCProxy(model).export_data(ids, fields)
+def datas_read(ids, model, fields, context=None):
+    ctx = context.copy()    
+    ctx.update(rpc.session.context)
+    return rpc.RPCProxy(model).export_data(ids, fields, ctx)
 
 def export_csv(fields, result, write_title=False):
     try:
@@ -80,8 +83,11 @@ def export_csv(fields, result, write_title=False):
     except IOError, (errno, strerror):
         raise common.message(_("Operation failed!\nI/O error")+"(%s)" % (errno,))
 
-def _fields_get_all(model, views):
+def _fields_get_all(model, views, context=None):
 
+    if not context:
+        context = {}
+        
     def parse(root, fields):
 
         for node in root.childNodes:
@@ -99,8 +105,8 @@ def _fields_get_all(model, views):
 
     proxy = rpc.RPCProxy(model)
 
-    v1 = proxy.fields_view_get(views.get('tree', False), 'tree', rpc.session.context)
-    v2 = proxy.fields_view_get(views.get('form', False), 'form', rpc.session.context)
+    v1 = proxy.fields_view_get(views.get('tree', False), 'tree', context)
+    v2 = proxy.fields_view_get(views.get('form', False), 'form', context)
 
     dom = xml.dom.minidom.parseString(v1['arch'].encode('utf-8'))
     root = dom.childNodes[0]
@@ -123,11 +129,15 @@ class ImpEx(SecuredController):
     @expose(template="templates/exp.mako")
     def exp(self, **kw):
         params, data = TinyDict.split(kw)
+        
+        ctx = params.context or {}
+        ctx.update(rpc.session.context.copy())
 
         views = {}
         if params.view_mode and params.view_ids:
             for i, view in enumerate(params.view_mode):
-                views[view] = params.view_ids[i]
+                if params.view_ids[i]:
+                    views[view] = params.view_ids[i]
 
 
         proxy = rpc.RPCProxy('ir.exports')
@@ -139,17 +149,18 @@ class ImpEx(SecuredController):
                                     headers=headers,
                                     url='/impex/get_fields',
                                     field_parent='relation',
+                                    context=ctx,
                                     views=views)
 
         tree.show_headers = False
 
-        view = proxy.fields_view_get(False, 'tree', rpc.session.context)
+        view = proxy.fields_view_get(False, 'tree', ctx)
         new_list = tw.listgrid.List(name='_terp_list', model='ir.exports', view=view, ids=None,
                                        domain=[('resource', '=', params.model)],
-                                       context=rpc.session.context, selectable=1, editable=False, pageable=False)
+                                       context=ctx, selectable=1, editable=False, pageable=False)
 
 
-        return dict(new_list=new_list, model=params.model, ids=params.ids,
+        return dict(new_list=new_list, model=params.model, ids=params.ids, ctx=ctx,
                     search_domain=params.search_domain, source=params.source,
                     tree=tree)
 
@@ -183,6 +194,13 @@ class ImpEx(SecuredController):
     def get_fields(self, model, prefix='', name='', field_parent=None, **kw):
 
         is_importing = kw.get('is_importing', False)
+        
+        ctx = {}
+        try:
+            ctx = eval(kw['context'])
+        except:
+            pass
+        ctx.update(rpc.session.context.copy())
 
         ids = kw.get('ids', '').split(',')
         ids = [i for i in ids if i]
@@ -193,7 +211,7 @@ class ImpEx(SecuredController):
         except:
             pass
 
-        fields = _fields_get_all(model, views)
+        fields = _fields_get_all(model, views, ctx)
         fields.update({'id': {'string': 'ID'}, 'db_id': {'string': 'Database ID'}})
 
         fields_order = fields.keys()
@@ -266,12 +284,15 @@ class ImpEx(SecuredController):
     def get_namelist(self, **kw):
 
         params, data = TinyDict.split(kw)
+        
+        ctx = params.context or {}
+        ctx.update(rpc.session.context.copy())
 
         res = []
         ids = []
         id = params.id
 
-        res = self.get_data(params.model)
+        res = self.get_data(params.model, ctx)
 
         ir_export = rpc.RPCProxy('ir.exports')
         ir_export_line = rpc.RPCProxy('ir.exports.line')
@@ -287,11 +308,14 @@ class ImpEx(SecuredController):
 
         return dict(name_list=name_list)
 
-    def get_data(self, model):
+    def get_data(self, model, context=None):
 
         name = ''
         prefix = ''
         ids = []
+        
+        if not context:
+            context = {}
 
         fields_data = {}
         proxy = rpc.RPCProxy(model)
@@ -299,10 +323,9 @@ class ImpEx(SecuredController):
 
         # XXX: in GTK client, top fields comes from Screen
         if not ids:
-            f1 = proxy.fields_view_get(False, 'tree', rpc.session.context)['fields']
-            f2 = proxy.fields_view_get(False, 'form', rpc.session.context)['fields']
+            f1 = proxy.fields_view_get(False, 'tree', context)['fields']
+            f2 = proxy.fields_view_get(False, 'form', context)['fields']
 
-            fields = {}
             fields.update(f1)
             fields.update(f2)
 
@@ -323,7 +346,7 @@ class ImpEx(SecuredController):
                     if fields[field].get('relation', False) and level>0:
                         fields2 = rpc.session.execute('object', 'execute', fields[field]['relation'], 'fields_get', False, rpc.session.context)
                         model_populate(fields2, prefix_node+field+'/', None, st_name+'/', level-1)
-
+            fields.update({'id':{'string':'ID'},'db_id':{'string':'Database ID'}})
             model_populate(fields)
 
             return _fields
@@ -339,31 +362,67 @@ class ImpEx(SecuredController):
         if isinstance(fields, basestring):
             fields = [fields]
 
-        ctx = {}
+        ctx = params.context or {}
         ctx.update(rpc.session.context.copy())
         ctx['import_comp'] = import_compat
 
         domain = params.seach_domain or []
 
         ids = params.ids or proxy.search(domain, 0, 0, 0, ctx)
-        result = datas_read(ids, params.model, fields)
+        result = datas_read(ids, params.model, fields, context=ctx)
         
         if result.get('warning', False):
-            common.message_box(_('Export Error!'), unicode(result.get('warning', False)))
+            common.warning(unicode(result.get('warning', False)), _('Export Error!'))
             return False
         result = result.get('datas',[])
         
         if import_compat:
             params.fields2 = fields
 
-        if export_as == 'excel':
-            #add_names = True
-            pass
-        return export_csv(params.fields2, result, add_names)
+        if export_as == 'xls':
+            try:            
+                import xlwt
+            except Exception, e:
+                  raise common.warning(_('Please Install xlwt Library.\nTo create spreadsheet files compatible with MS Excel.'), _('Import Error.')) 
+                   
+            ezxf = xlwt.easyxf
+          
+            fp = StringIO.StringIO()
+          
+            wb = xlwt.Workbook()
+            worksheet = wb.add_sheet('Sheet 1')
+          
+            for col in range(len(params.fields2)):
+                worksheet.write(0, col, ustr(params.fields2[col]))
+                col+1
+                
+            heading_xf = ezxf('align: wrap yes')
+
+            for data in range(len(result)):
+                for d in range(len(result[data])):
+                    try:
+                        result[data][d] = ustr(result[data][d])
+                    except:
+                        pass
+                    result[data][d] = re.sub("\r", " ", result[data][d])
+                    worksheet.write(data+1, d, result[data][d], heading_xf)
+                    worksheet.col(d).width = 8000  
+                    d+1   
+            
+            wb.save(fp)            
+
+            fp.seek(0)
+            data = fp.read()          
+            return data
+        else:
+            return export_csv(params.fields2, result, add_names)
 
     @expose(template="templates/imp.mako")
     def imp(self, **kw):
         params, data = TinyDict.split(kw)
+        
+        ctx = params.context or {}
+        ctx.update(rpc.session.context.copy())
 
         views = {}
         if params.view_mode and params.view_ids:
@@ -377,6 +436,7 @@ class ImpEx(SecuredController):
                                     url='/impex/get_fields',
                                     field_parent='relation',
                                     views=views,
+                                    context=ctx,
                                     is_importing=1)
 
         tree.show_headers = False
@@ -389,6 +449,9 @@ class ImpEx(SecuredController):
 
         _fields = {}
         _fields_invert = {}
+        
+        proxy = rpc.RPCProxy(params.model)
+        fields = proxy.fields_get(False, rpc.session.context)
 
         def model_populate(fields, prefix_node='', prefix=None, prefix_value='', level=2):
             def str_comp(x,y):
@@ -399,16 +462,25 @@ class ImpEx(SecuredController):
             fields_order = fields.keys()
             fields_order.sort(lambda x,y: str_comp(fields[x].get('string', ''), fields[y].get('string', '')))
             for field in fields_order:
-                if (fields[field]['type'] not in ('reference',)) and (not fields[field].get('readonly', False)):
+                if (fields[field].get('type','') not in ('reference',))\
+                            and (not fields[field].get('readonly', False)\
+                            or not dict(fields[field].get('states', {}).get(
+                            'draft', [('readonly', True)])).get('readonly',True)):
+                    
                     st_name = prefix_value+fields[field]['string'] or field
                     _fields[prefix_node+field] = st_name
                     _fields_invert[st_name] = prefix_node+field
-                    if fields[field]['type']=='one2many' and level>0:
+                    if fields[field].get('type','')=='one2many' and level>0:
                         fields2 = rpc.session.execute('object', 'execute', fields[field]['relation'], 'fields_get', False, rpc.session.context)
+                        fields2.update({'id': {'type': 'char', 'string': 'ID'}, 'db_id':{'type': 'char', 'string': 'Database ID'}})
                         model_populate(fields2, prefix_node+field+'/', None, st_name+'/', level-1)
-
-        proxy = rpc.RPCProxy(params.model)
-        fields = proxy.fields_get(False, rpc.session.context)
+                    if fields[field].get('type','') in ('many2one', 'many2many' ) and level>0:
+#                        _fields[field+':id'] = fields[field]['string']    same in GTK
+#                        _fields_invert[fields[field]['string']] = field+':id' same in GTK
+                        model_populate({'id': {'type': 'char', 'string': 'ID'}, 'db_id': {'type': 'char', 'string': 'Database ID'}},
+                                        prefix_node+field+':', None, st_name+'/', level-1)
+        
+        fields.update({'id': {'type': 'char', 'string': 'ID'}, 'db_id': {'type': 'char', 'string': 'Database ID'}})
         model_populate(fields)
 
         try:
@@ -422,7 +494,12 @@ class ImpEx(SecuredController):
             for line in data:
                 for word in line:
                     word = ustr(word.decode(csvcode))
-                    fields += [(_fields_invert[word], word)]
+                    if word in _fields:
+                        fields += [(word, _fields[word])]
+                    elif word in _fields_invert.keys():
+                        fields += [(_fields_invert[word], word)]
+                    else:
+                        raise common.warning(_("You cannot import this field %s, because we cannot auto-detect it" % (word,)))
                 break
         except:
             raise common.warning(_('Error processing your first line of the file.\nField %s is unknown!') % (word,), _('Import Error.'))
@@ -445,7 +522,10 @@ class ImpEx(SecuredController):
             fields = [fields]
 
         for line in data:
-            datas.append(map(lambda x:x.decode(csvcode).encode('utf-8'), line))
+            try:
+                datas.append(map(lambda x:x.decode(csvcode).encode('utf-8'), line))
+            except:
+                datas.append(map(lambda x:x.decode('latin').encode('utf-8'), line))
         try:
             res = rpc.session.execute('object', 'execute', params.model, 'import_data', fields, datas)
         except Exception, e:
