@@ -65,11 +65,7 @@ class OpenO2M(Form):
 
         # to get proper view, first generate form using the view_params
         vp = params.view_params
-        
-        # this prevents calling default_get, causes unnecessary 
-        # auto increment of sequence
-        vp.id = params.parent_id or False 
-        
+                
         form = tw.form_view.ViewForm(vp, name="view_form", action="/openo2m/save")
         cherrypy.request.terp_validators = {}
         wid = form.screen.widget.get_widgets_by_name(params.o2m)[0]
@@ -83,14 +79,19 @@ class OpenO2M(Form):
         
         # IE hack, get context from cookies (see o2m.js)
         o2m_context = {}
+        parent_context = {}
         try:
             o2m_context = urllib.unquote(cherrypy.request.cookie['_terp_o2m_context'].value)
+            parent_context = urllib.unquote(cherrypy.request.cookie['_terp_parent_context'].value)
             cherrypy.request.cookie['_terp_o2m_context']['expires'] = 0
             cherrypy.response.cookie['_terp_o2m_context']['expires'] = 0
+            cherrypy.request.cookie['_terp_parent_context']['expires'] = 0
+            cherrypy.response.cookie['_terp_parent_context']['expires'] = 0
         except:
             pass
         
-        params.o2m_context = o2m_context
+        params.o2m_context = params.o2m_context or o2m_context
+        params.parent_context = params.parent_context or parent_context
         
         ctx = params.context or {}
         ctx.update(params.parent_context or {})
@@ -156,8 +157,9 @@ class OpenO2M(Form):
         new_ids = [i for i in all_ids if i not in ids]
 
         current.ids = all_ids
-        #if new_ids:
-        #    current.id = new_ids[0]
+        if new_ids and params.source:
+            current.id = new_ids[-1]
+            params.o2m_id = current.id
             
         # perform button action
         if params.button:
@@ -168,12 +170,6 @@ class OpenO2M(Form):
             if res:
                 return res
 
-        # If new O2M action, get the newly created id
-        if params.source:
-            field = prefix.split('/')[-1]
-            current.id = proxy.read([params.parent_id], [field], ctx)[0][field][0]
-            params.o2m_id = current.id
-
         return self.create(params)
 
     @expose()
