@@ -273,7 +273,7 @@ class ViewEd(SecuredController):
             def _find(node, node2):
                 # Check if xpath query or normal inherit (with field matching)
                 if node2.nodeType==node2.ELEMENT_NODE and node2.localName=='xpath':
-                    res = tools.xml_locate(node2.getAttribute('expr'), node)
+                    res = tools.get_xpath(node, node2.getAttribute('expr'))
                     return res and res[0]
                 else:
                     if node.nodeType==node.ELEMENT_NODE and node.localName==node2.localName:
@@ -405,7 +405,7 @@ class ViewEd(SecuredController):
 
         return dict(records=records)
 
-    @expose(template="templates/viewed_edit.mako")
+    @expose(template="templates/viewed_edit.mako", methods=('POST',))
     def edit(self, view_id, xpath_expr):
         view_id = int(view_id)
 
@@ -482,7 +482,7 @@ class ViewEd(SecuredController):
 
         return dict(view_id=view_id, xpath_expr=xpath_expr, nodes=nodes, fields=fields, model=model, positions=positions)
 
-    @expose('json')
+    @expose('json', methods=('POST',))
     def create_view(self, view_id=False, xpath_expr=None, **kw):
 
         view_id = int(view_id)
@@ -537,7 +537,7 @@ class ViewEd(SecuredController):
 
         return dict(record=record, error=error)
 
-    @expose('json')
+    @expose('json', methods=('POST',))
     def remove_view(self, view_id, **kw):
 
         view_id = int(view_id)
@@ -553,7 +553,7 @@ class ViewEd(SecuredController):
 
         return dict()
 
-    @expose('json')
+    @expose('json', methods=('POST',))
     def save(self, _terp_what, view_id, xpath_expr, **kw):
 
         view_id = int(view_id)
@@ -644,7 +644,7 @@ class ViewEd(SecuredController):
 
         return dict(record=record)
 
-    @expose()
+    @expose(methods=('POST',))
     def update_dashboard(self, view_id, dst, src, ref=None):
 
         error = None
@@ -752,7 +752,7 @@ _PROPERTIES = {
     'image' : ['filename', 'width', 'height', 'groups'],
     'separator' : ['string', 'colspan', 'groups'],
     'label': ['string', 'align', 'colspan', 'groups'],
-    'button': ['name', 'string', 'icon', 'type', 'states', 'readonly', 'special', 'target', 'confirm', 'attrs', 'groups'],
+    'button': ['name', 'string', 'icon', 'type', 'states', 'readonly', 'special', 'target', 'confirm', 'context', 'attrs', 'groups'],
     'newline' : [],
     'hpaned': ['position', 'groups'],
     'vpaned': ['position', 'groups'],
@@ -879,8 +879,7 @@ class GroupsProperty(tw.SelectField):
 class ActionProperty(tw.many2one.M2O):
 
     def __init__(self, name, default=None):
-        attrs = dict(name=name, relation='ir.actions.actions')
-        super(ActionProperty, self).__init__(attrs)
+        super(ActionProperty, self).__init__(name=name, relation='ir.actions.actions')
         self.set_value(default or False)
 
 class IconProperty(tw.SelectField):
