@@ -80,7 +80,7 @@ class Wizard(SecuredController):
         while state != 'end':
 
             ctx = rpc.session.context.copy()
-            ctx.update(params.context or {})
+            ctx.update(datas.get('context' or {}) or {})
 
             res = rpc.session.execute('wizard', 'execute', wiz_id, datas, state, ctx)
 
@@ -97,6 +97,9 @@ class Wizard(SecuredController):
                 for f in fields:
                     if 'value' in fields[f]:
                         form_values[f] = fields[f]['value']
+                        
+                    if f in datas['form'] and fields[f]['type'] == "one2many":
+                        datas['form'][f] = [(1, d, {}) for d in datas['form'][f]]
 
                 form_values.update(datas['form'])
 
@@ -173,7 +176,10 @@ class Wizard(SecuredController):
             params = cherrypy.session['wizard_parent_params']
 
             frm = eval('cherrypy.request.app.root' + frm.replace('/', '.'))
-            return frm.create(params)
+            try:
+                return frm.create(params)
+            except:
+                pass  
 
         return """<html>
             <head>
