@@ -121,13 +121,10 @@ class RPCGateway(object):
 
     def __execute(self, obj, method, args=(), auth=True):
         try:
-            
-            #print "TERP-CALLING:", obj, method, args
             result = self.__rpc__(obj, method, args, auth=auth)
-            #print "TERP-RESULT:", result
             return self.__convert(result)
 
-        except socket.error, (e1, e2):
+        except socket.error:
             raise common.message(_('Connection refused!'))
 
         except RPCException, err:
@@ -136,6 +133,8 @@ class RPCGateway(object):
                     raise common.concurrency(err.message, err.data, args)
                 else:
                     raise common.warning(err.data)
+            elif err.code == 'AccessDenied':
+                raise common.error(_('Access Denied'), err.code)
             else:
                 raise common.error(_('Application Error!'), err.backtrace)
 
@@ -284,8 +283,10 @@ class RPCSession(object):
     def listdb(self):
         try:
             return self.execute_noauth('db', 'list')
-        except Exception, e:
-            return -1
+        except common.TinyError, e:
+            if e.message == 'AccessDenied':
+                return None
+            raise
 
     def login(self, db, user, password):
         
