@@ -148,6 +148,7 @@ var switch_O2M = function(view_type, src){
     
     params['_terp_source'] = src;
     params['_terp_source_view_type'] = view_type;
+    params['_terp_editable'] = $(prefix + '_terp_editable').value
     
     if (getElement('_terp_list')){
         var ids = new ListView('_terp_list').getSelectedRecords();
@@ -325,21 +326,34 @@ var pager_action = function(action, src) {
     return src ? new ListView(src).go(action) : submit_search_form(action);
 }
 
-var buttonClicked = function(name, btype, model, id, sure, target){
+var buttonClicked = function(name, btype, model, id, sure, target, context){
 
     if (sure && !confirm(sure)){
         return;
     }
 
+    //var button = getElement(name);
+    //var context = getNodeAttribute(button, "context");
+
     var params = {};
 
     params['_terp_button/name'] = name;
     params['_terp_button/btype'] = btype;
     params['_terp_button/model'] = model;
     params['_terp_button/id'] = id;
+
+    if (!context || context == "{}") {
+        var act = get_form_action(btype == 'cancel' ? 'cancel' : 'save', params);
+        return submit_form(act, null, target);
+    }
+
+    var req = eval_domain_context_request({source: "", domain: "[]", context: context});
+    req.addCallback(function(obj) {
+        params['_terp_button/context'] = obj.context || 0;
     
-    var act = get_form_action(btype == 'cancel' ? 'cancel' : 'save', params);
-    submit_form(act, null, target);
+        var act = get_form_action(btype == 'cancel' ? 'cancel' : 'save', params);
+        submit_form(act, null, target);
+    });
 }
 
 var onBooleanClicked = function(name) {
@@ -464,7 +478,16 @@ var getFormData = function(extended) {
             if (kind == "picture") {
                 n = e.id;
             }
-
+            
+            if (kind == 'text_html') {
+                if(tinyMCE.get(e.name))
+                    attrs['value'] =  tinyMCE.get(e.name).getContent();
+            }
+            
+            if (kind == 'reference' && value) { 
+                attrs['value'] = "[" + value + ",'" + getNodeAttribute(e, 'relation') + "']";
+            }
+            
             // stringify the attr object
             frm[n] = serializeJSON(attrs);
             
@@ -589,6 +612,26 @@ var onChange = function(name) {
                 if (kind == 'boolean') {
                     $(prefix + k + '_checkbox_').checked = value || false;
                 }
+                
+                
+                if (kind=='text_html') {
+                    if(tinyMCE.get(prefix+k))
+                        tinyMCE.execInstanceCommand(prefix+k, 'mceSetContent', false, value || '')
+                }
+
+                if (kind=='selection') {
+                    if (typeof(value)=='object') {
+                        var opts = [OPTION({'value': ''})];
+                        for (i in value) {
+                            var item = value[i];
+                            opts.push(OPTION({'value': item[0]}, item[1]));
+                        }
+                        MochiKit.DOM.replaceChildNodes(fld, map(function(x){return x;}, opts));
+                    }
+                    else {
+                        fld.value = value
+                    }
+                }
 
                 MochiKit.Signal.signal(fld, 'onchange');
             }
@@ -858,10 +901,10 @@ function do_report(id, relation) {
     window.open(getURL(act, params));
 }
 
-function do_action(action_id, field, relation, src) {
-    
+function do_action(action_id, field, relation, src, data) {
+
     var params = {};
-    
+
     if ($('_terp_list')) {
         var list = new ListView('_terp_list');
         var ids = list.getSelectedRecords();
@@ -871,9 +914,11 @@ function do_action(action_id, field, relation, src) {
         }
 
         params['_terp_selection'] = '[' + ids.join(',') + ']';
+        var id = eval(params['_terp_selection'])[0]
     }
-
-    var id = $(field).value;
+	else{
+    	var id = $(field).value;}
+    	
     var domain = getNodeAttribute(src, 'domain');
     var context = getNodeAttribute(src, 'context');
     
@@ -888,11 +933,12 @@ function do_action(action_id, field, relation, src) {
         var act = get_form_action('action');
         MochiKit.Base.update(params, {
             '_terp_action': action_id,
-            '_terp_domain': obj.domain, 
-            '_terp_context': obj.context, 
+            '_terp_domain': obj.domain,
+            '_terp_context': obj.context,
             '_terp_id': id,
-            '_terp_model': relation});
-        
+            '_terp_model': relation,
+            'datas': data});
+
         window.open(getURL(act, params));
 
     });
