@@ -325,6 +325,16 @@ MochiKit.Base.update(ListView.prototype, {
                 if (obj.result && obj.result.url) {
                     window.open(obj.result.url);
                 }
+                
+                if(obj.wiz_result){                    
+                    var act = get_form_action('action');                    
+                    MochiKit.Base.update(params, {
+                        '_terp_action': obj.wiz_result.action_id,
+                        '_terp_id': obj.wiz_result.id,
+                        '_terp_model': obj.wiz_result.model});
+                    
+                    window.open(getURL(act, params));
+                }
 
                 if (obj.reload) {
                     window.location.reload();
@@ -353,7 +363,7 @@ MochiKit.Base.update(ListView.prototype, {
         }
 
         var parent_field = this.name.split('/');
-        var data = getFormData(true);
+        var data = getFormData(2);
         var args = getFormParams('_terp_concurrency_info');
 
         for(var k in data) {
@@ -416,7 +426,7 @@ MochiKit.Base.update(ListView.prototype, {
         if(!ids) {
             var ids = this.getSelectedRecords();
             if(ids.length > 0){
-                ids = '[' + ids.join(', ') + ']';
+                ids = '[' + ids.join(',') + ']';
             }
         }
         
@@ -436,7 +446,11 @@ MochiKit.Base.update(ListView.prototype, {
             if (obj.error){
                 alert(obj.error);
             } else {
+                if(obj.msg) {
+                    getElement('request_messages').innerHTML = obj.msg
+                }
                 self.reload();
+                
             }
         });
     },
@@ -483,12 +497,15 @@ MochiKit.Base.update(ListView.prototype, {
 
         var self = this;
         var args = this.makeArgs();
+        
+        var current_id = edit_inline ? (parseInt(edit_inline) || 0) : edit_inline;
 
         // add args
         args['_terp_source'] = this.name;
         args['_terp_edit_inline'] = edit_inline;
         args['_terp_source_default_get'] = default_get_ctx;
         args['_terp_concurrency_info'] = concurrency_info;
+        args['_terp_editable'] = $('_terp_editable').value;
 
         if (this.name == '_terp_list') {
             args['_terp_search_domain'] = $('_terp_search_domain').value;
@@ -501,8 +518,16 @@ MochiKit.Base.update(ListView.prototype, {
             var _terp_ids = $(self.name + '/_terp_ids') || $('_terp_ids');
             var _terp_count = $(self.name + '/_terp_count') || $('_terp_count');
             
+            _terp_id.value = current_id > 0 ? current_id : 'False';
+            
             if(obj.ids) {
-                _terp_id.value = obj.ids.length ? obj.ids[0] : 'False';
+            
+                if (typeof(current_id) == "undefined" && obj.ids.length) {
+                    current_id = obj.ids[0];
+                }
+            
+                _terp_id.value = current_id > 0 ? current_id : 'False';
+                
                 _terp_ids.value = '[' + obj.ids.join(',') + ']';
                 _terp_count.value = obj.count;
             }
@@ -538,7 +563,6 @@ MochiKit.Base.update(ListView.prototype, {
                     var items = getElementsByAttribute(['name', '_terp_concurrency_info'], ['value', '*=' + key]);
                     var value = "('" + key + "', '" + obj.info[key] + "')";
                     for(var i=0; i<items.length;i++) {
-                        log(key, value);
                         items[i].value = value;
                     }
                 }catch(e){}
@@ -579,7 +603,8 @@ MochiKit.Base.update(ListView.prototype, {
         
         ids = '[' + ids.join(',') + ']';
         
-        openWindow(getURL('/impex/exp', {_terp_model: this.model, 
+        openWindow(getURL('/impex/exp', {_terp_model: this.model,
+        								 _terp_context: $('_terp_context').value, 
                                          _terp_source: this.name, 
                                          _terp_search_domain: $('_terp_search_domain').value, 
                                          _terp_ids: ids,
@@ -589,6 +614,7 @@ MochiKit.Base.update(ListView.prototype, {
 
     importData: function(){
         openWindow(getURL('/impex/imp', {_terp_model: this.model,
+        								 _terp_context: $('_terp_context').value,
                                          _terp_source: this.name,
                                          _terp_view_ids : this.view_ids,
                                          _terp_view_mode : this.view_mode}));
