@@ -193,7 +193,11 @@ def render_template(template, kw):
     return utils.NoEscape(template.render_unicode(**kw))
 
 
-def expose(format='html', template=None, content_type=None, allow_json=False):
+def expose(format='html', template=None, content_type=None, allow_json=False, methods=None):
+
+    if methods is not None:
+        assert isinstance(methods, (list, tuple))
+        methods = tuple([m.upper() for m in methods])
 
     def expose_wrapper(func):
         
@@ -201,6 +205,9 @@ def expose(format='html', template=None, content_type=None, allow_json=False):
 
         def func_wrapper(*args, **kw):
 
+            if methods and cherrypy.request.method.upper() not in methods:
+                raise cherrypy.HTTPError(405)
+
             res = func(*args, **kw)
             
             if format == 'json' or (allow_json and 'allow_json' in cherrypy.request.params):
