@@ -237,7 +237,7 @@ class Widget(object):
     
     def __repr__(self):
         return self.__class__.__name__
-        return "%s(%s)" % (self.__class__.__name__, ', '.join(
+        return "%s(%s)" % (self.__class__.__name__, ','.join(
             ["%s=%r" % (var, getattr(self, var))
                 for var in ['name'] + list(self.__class__.params)]))
 
@@ -268,7 +268,12 @@ class InputWidget(Widget):
     @property
     def is_validated(self):
         try:
-            return self.root is cherrypy.request.validated_form
+            if self.root is cherrypy.request.validated_form:
+                return True
+            
+            for w in cherrypy.request.validated_form.iter_member_widgets():
+                if w is self.root:
+                    return True
         except:
             pass
         return False
