@@ -261,7 +261,7 @@ class Notebook(TinyInputWidget):
         
         self.fake_widget = '_fake'
         if attrs.get('prefix'):
-            self.fake_widge = attrs['prefix'] + '/_fake'
+            self.fake_widget = attrs['prefix'] + '/_fake'
 
 
 class Page(Frame):
@@ -404,7 +404,7 @@ class Float(TinyInputWidget):
         self.validator = validators.Float(digit=digit)
 
 #        if not self.default:
-#            self.default = 0.0
+#            self.default = format.format_decimal(float(0.0), digit)
 
     def set_value(self, value):
         self.default = value
@@ -559,7 +559,7 @@ class Hidden(TinyInputWidget):
 class Button(TinyInputWidget):
 
     template = "templates/button.mako"
-    params = ["btype", "id", "confirm", "icon", "target"]
+    params = ["btype", "id", "confirm", "icon", "target", "context"]
 
     visible = True
     target = 'current'
@@ -572,9 +572,9 @@ class Button(TinyInputWidget):
         self.string = re.sub('_(?!_)', '', self.string or '')
 
         self.btype = attrs.get('special', attrs.get('type', 'workflow'))
+        self.context = attrs.get("context") or {}
 
         self.nolabel = True
-        self.readonly = False
 
         if self.icon:
             self.icon = icons.get_icon(self.icon)
@@ -662,7 +662,7 @@ class Form(TinyInputWidget):
     params = ['id']
     member_widgets = ['frame', 'concurrency_info']
 
-    def __init__(self, prefix, model, view, ids=[], domain=[], context={}, editable=True, readonly=False, nodefault=False, nolinks=1):
+    def __init__(self, prefix, model, view, ids=[], domain=[], context={}, editable=True, readonly=False, nodefault=False, nolinks=1, is_wizard=False):
 
         super(Form, self).__init__(prefix=prefix, model=model, editable=editable, readonly=readonly, nodefault=nodefault)
 
@@ -673,7 +673,7 @@ class Form(TinyInputWidget):
 
         self.string = attrs.get('string', '')
         self.link = attrs.get('link', nolinks)
-
+        self.is_wizard = is_wizard
         self.id = None
         self.context = context or {}
 
@@ -695,9 +695,11 @@ class Form(TinyInputWidget):
                     values[d[0]] = d[2][0]
 
         if ids:
-            values = proxy.read(ids[:1], fields.keys() + ['__last_update'], ctx)[0]
-            self.id = ids[0]
-            self._update_concurrency_info(self.model, [values])
+            lval = proxy.read(ids[:1], fields.keys() + ['__last_update'], ctx)
+            if lval:
+                values = lval[0]
+                self.id = ids[0]
+                self._update_concurrency_info(self.model, [values])
 
         elif 'datas' in view: # wizard data
 
@@ -789,11 +791,11 @@ class Form(TinyInputWidget):
                 n = self.parse(prefix=prefix, root=node, fields=fields, values=values)
                 views += [Frame(children=n, **attrs)]
 
-            elif node.localName == 'notebook':
-                self.nb_couter += 1
+            elif node.localName == 'notebook':                
                 n = self.parse(prefix=prefix, root=node, fields=fields, values=values)
                 nb = Notebook(children=n, **attrs)
-                nb._name = prefix.replace('/', '_') + '_notebook_%s'  % (self.nb_couter)
+                self.nb_couter += 1
+                nb._name = prefix.replace('/', '_') + '_notebook_%s'  % (self.nb_couter)                
                 views += [nb]
 
             elif node.localName == 'page':
@@ -808,6 +810,7 @@ class Form(TinyInputWidget):
                 name = attrs['name']
 
                 try:
+                    fields[name]['link'] = attrs.get('link', '1')
                     fields[name].update(attrs)
                 except:
                     print "-"*30,"\n malformed tag for:", attrs
@@ -856,7 +859,8 @@ class Form(TinyInputWidget):
     def _make_field_widget(self, attrs, value=False):
 
         attrs['editable'] = self.editable
-        attrs['link'] = self.link
+        if not attrs['type'] == 'many2one':
+            attrs['link'] = self.link
 
         attrs.setdefault('context', self.context)
         attrs.setdefault('model', self.model)
@@ -876,6 +880,9 @@ class Form(TinyInputWidget):
 
         if kind == 'image' or kind == 'picture':
             attrs['id'] = self.id
+            
+        if kind == 'binary':
+            attrs['is_wizard'] = self.is_wizard
 
         # suppress by container's readonly property
         if self.readonly:
