@@ -82,14 +82,13 @@ class Graph(TinyWidget):
         //alert(path);
         window.location.href = path;
     }
-    """),
-    JSLink("openerp", "javascript/swfobject.js")]
+    """)]
 
     params = ['width', 'height', 'data']
     width = 500
     height = 350
 
-    def __init__(self, model, view=False, view_id=False, ids=[], domain=[], context={}, width=500, height=350):
+    def __init__(self, model, view=False, view_id=False,view_ids=False, ids=[], domain=[], context={}, width=500, height=350):
 
         name = 'graph_%s' % (random.randint(0,10000))
         super(Graph, self).__init__(name=name, model=model, width=width, height=height)
@@ -112,7 +111,7 @@ class Graph(TinyWidget):
             self.ids = rpc.RPCProxy(model).search(domain, 0, 0, 0, ctx)
             
         if chart_type == "bar":
-            self.data = BarChart(model, view, view_id, ids, domain, context)
+            self.data = BarChart(model, view, view_id, view_ids, ids, domain, context)
         else:
             self.data = PieChart(model, view, view_id, ids, domain, context)
             
@@ -121,7 +120,6 @@ class Graph(TinyWidget):
 class GraphData(object):
 
     def __init__(self, model, view=False, view_id=False, ids=[], domain=[], context={}):
-
         ctx = {}
         ctx = rpc.session.context.copy()
         ctx.update(context)
@@ -159,28 +157,38 @@ class GraphData(object):
             res['temp_id'] = value.get('id')
 
             for x in axis_data.keys():
-                if fields[x]['type'] in ('many2one', 'char','time','text','selection'):
+                if fields[x]['type'] in ('many2one', 'char', 'time', 'text'):
                     res[x] = value[x]
                     if isinstance(res[x], (list, tuple)):
                         res[x] = res[x][-1]
                     res[x] = ustr(res[x])
-                elif fields[x]['type'] == 'date' and value[x]:
-                    date = time.strptime(value[x], DT_FORMAT)
-                    res[x] = time.strftime(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y'), date)
-                elif fields[x]['type'] == 'datetime' and value[x]:
-                    date = time.strptime(value[x], DHM_FORMAT)
-                    if 'tz' in rpc.session.context:
-                        try:
-                            import pytz
-                            lzone = pytz.timezone(rpc.session.context['tz'])
-                            szone = pytz.timezone(rpc.session.timezone)
-                            dt = DT.datetime(date[0], date[1], date[2], date[3], date[4], date[5], date[6])
-                            sdt = szone.localize(dt, is_dst=True)
-                            ldt = sdt.astimezone(lzone)
-                            date = ldt.timetuple()
-                        except:
-                            pass
-                    res[x] = time.strftime(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y')+' %H:%M:%S', date)
+                elif fields[x]['type'] in 'selection': 
+                    for i in fields[x]['selection']:
+                        if value[x] in i:
+                            res[x] = i[1]
+                elif fields[x]['type'] == 'date':
+                    if value[x]:
+                        date = time.strptime(value[x], DT_FORMAT)
+                        res[x] = time.strftime(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y'), date)
+                    else:
+                        res[x] = ''
+                elif fields[x]['type'] == 'datetime':
+                    if value[x]:
+                        date = time.strptime(value[x], DHM_FORMAT)
+                        if 'tz' in rpc.session.context:
+                            try:
+                                import pytz
+                                lzone = pytz.timezone(rpc.session.context['tz'])
+                                szone = pytz.timezone(rpc.session.timezone)
+                                dt = DT.datetime(date[0], date[1], date[2], date[3], date[4], date[5], date[6])
+                                sdt = szone.localize(dt, is_dst=True)
+                                ldt = sdt.astimezone(lzone)
+                                date = ldt.timetuple()
+                            except:
+                                pass
+                        res[x] = time.strftime(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y')+' %H:%M:%S', date)
+                    else:
+                        res[x] = ''
                 else:
                     res[x] = float(value[x])
 
@@ -190,7 +198,7 @@ class GraphData(object):
                 res['id'] = value[axis[0]]
             else:
                 res['id'] = False
-
+            
             res['rec_id'] = rec_ids
 
             self.values.append(res)
@@ -331,6 +339,7 @@ class GraphData(object):
         stack_id_list = []
         val = []
         grp_value = []
+        grp_data = []
         
         if len(axis_group) > 1 and kind == 'bar':
             
@@ -356,7 +365,7 @@ class GraphData(object):
                                 if dt == dts[axis[0]] and d == dts[group_field] and dt == key:
                                     ids += [dts['temp_id']]
                                     group_data[key][d] = str(data[dt][d]) + '/' + str(ids)
-                
+                                    
                 for y in range(len(axis_group)):
                     for field in axis[1:]:
                         values[field] = [data[x].get(axis_group[y], 0.0) for x in new_keys]
@@ -368,6 +377,7 @@ class GraphData(object):
                         grp_value.append(grp_v)
                 stack_list += val
                 stack_id_list += grp_value
+            
                 
 #        IF VALUES ARE ALL 0...
 #        if stack_list and len(stack_list) > 0:
@@ -382,9 +392,10 @@ class GraphData(object):
 
 class BarChart(GraphData):
 
-    def __init__(self, model, view=False, view_id=False, ids=[], domain=[], context={}):
+    def __init__(self, model, view=False, view_id=False,view_ids=False, ids=[], domain=[], context={}):
         super(BarChart, self).__init__(model, view, view_id, ids, domain, context)
         self.context = context
+        self.view_ids = view_ids
 
     def get_data(self):
 
@@ -472,7 +483,7 @@ class BarChart(GraphData):
             temp_lbl.append(lbl)
 
         url = []
-
+        
         for x in axis[1:]:
             if len(axis_group) > 1:
                 for st in stack_id_list:
@@ -481,16 +492,22 @@ class BarChart(GraphData):
                             ids = s.split('/')[1]
                             ids = eval(ids)
                             dom = [('id', 'in', ids)]
-                            u = tools.url_plus('/form/find', _terp_view_type='tree', _terp_view_mode="['tree', 'graph']",
-                               _terp_domain=ustr(dom), _terp_model=self.model, _terp_context=ustr(ctx))
-        
+                            if len(self.view_ids) > 2 or self.view_ids[0]:
+                                u = tools.url_plus('/form/find', _terp_view_type='tree', _terp_view_mode="['form','tree', 'graph']",
+                                   _terp_domain=ustr(dom), _terp_model=self.model, _terp_context=ustr(ctx),_terp_view_ids = self.view_ids)
+                            else:
+                                u = tools.url_plus('/form/find', _terp_view_type='tree', _terp_view_mode="['tree', 'graph']",
+                                   _terp_domain=ustr(dom), _terp_model=self.model, _terp_context=ustr(ctx))
                             url.append(u)
             
             else:
                 for dom in domain:
-                    u = tools.url_plus('/form/find', _terp_view_type='tree', _terp_view_mode="['tree', 'graph']",
-                           _terp_domain=ustr(dom), _terp_model=self.model, _terp_context=ustr(ctx))
-    
+                    if len(self.view_ids) > 2 or self.view_ids[0]:
+                        u = tools.url_plus('/form/find', _terp_view_type='tree', _terp_view_mode="['form','tree', 'graph']",
+                               _terp_domain=ustr(dom), _terp_model=self.model, _terp_context=ustr(ctx),_terp_view_ids = self.view_ids)
+                    else:
+                        u = tools.url_plus('/form/find', _terp_view_type='tree', _terp_view_mode="['tree', 'graph']",
+                                   _terp_domain=ustr(dom), _terp_model=self.model, _terp_context=ustr(ctx))
                     url.append(u)
         
         allvalues = []
@@ -532,13 +549,15 @@ class BarChart(GraphData):
                 all_keys.append(data)
 
             stack_val = []
+            cnt = 0
             for j, stk in enumerate(stack_list):
                 sval = []
                 for x, s in enumerate(stk):
                     stack = {}
                     stack['val'] = s
-                    if s != 0.0:
-                        stack["on-click"]= "function(){onChartClick('" + url[x] + "')}"
+                    if s != 0.0 and not ctx.get('report_id', False):
+                        stack["on-click"]= "function(){onChartClick('" + url[cnt] + "')}"
+                        cnt += 1
                     stack['tip'] = s
                     sval.append(stack)
                 stack_val.append(sval)
@@ -562,7 +581,8 @@ class BarChart(GraphData):
     
                 for j, d in enumerate(data):
                     dt = {}
-                    dt["on-click"]= "function(){onChartClick('" + url[j] + "')}"
+                    if not ctx.get('report_id', False):
+                        dt["on-click"]= "function(){onChartClick('" + url[j] + "')}"
                     dt['top'] = d
                     datas.append(dt)
                     allvalues.append(d)
@@ -632,7 +652,8 @@ class PieChart(GraphData):
             val['value'] = value[i]
             val['text'] = x
             val['label'] = x
-            val['on-click'] = "function(){onChartClick('" + url[i] + "')}"
+            if not ctx.get('report_id'):
+                val['on-click'] = "function(){onChartClick('" + url[i] + "')}"
             
             if total_val <> 0.0:
                 field_key = (100 * value[i])/total_val
