@@ -68,7 +68,6 @@ class List(TinyWidget):
     buttons = []
 
     edit_inline = None
-
     data = None
     columns = 0
     headers = None
@@ -105,7 +104,8 @@ class List(TinyWidget):
         self.offset = kw.get('offset', 0)
         self.limit = kw.get('limit', 0)
         self.count = kw.get('count', 0)
-        self.link = kw.get('nolinks')
+        self.link = kw.get('nolinks', 1)
+        self.attr_limit = 0
         self.m2m = False
         self.concurrency_info = None
         self.selector = None
@@ -122,11 +122,11 @@ class List(TinyWidget):
 
         attrs = tools.node_attributes(root)
         self.string = attrs.get('string','')
-        
+
         # is relational field (M2M/O2M)
-        if self.source:
-            self.limit = cherrypy.request.app.config['openerp-web'].get('child.listgrid.limit', self.limit) 
-            self.min_rows = cherrypy.request.app.config['openerp-web'].get('child.listgrid.min_rows', 5)
+        if self.source:            
+            self.attr_limit = cherrypy.request.app.config['openerp-web'].get('child.listgrid.limit', 20)
+            self.attr_limit = int(attrs.get('limit', self.attr_limit))            
         else:
             self.min_rows = 5
 
@@ -136,7 +136,9 @@ class List(TinyWidget):
             pass
 
         try:
-            self.limit = int(attrs.get('limit'))
+            if self.limit == 0:
+                self.limit = self.attr_limit
+
         except:
             pass
 
@@ -158,13 +160,20 @@ class List(TinyWidget):
 
         self.data_dict = {}
         data = []
-        
+
+        if ids and not isinstance(ids, list):
+            ids = [ids]
+
         if ids and len(ids) > 0:
 
             ctx = rpc.session.context.copy()
             ctx.update(context)
-
-            data = proxy.read(ids, fields.keys() + ['__last_update'], ctx)
+            
+            if self.limit and len(ids) > self.limit and self.limit != -1:
+                new_ids = ids[self.offset:self.offset+self.limit]
+                data = proxy.read(new_ids, fields.keys() + ['__last_update'], ctx)
+            else:
+                data = proxy.read(ids, fields.keys() + ['__last_update'], ctx)
             self._update_concurrency_info(self.model, data)
             self.concurrency_info = ConcurrencyInfo(self.model, ids)
 
@@ -172,7 +181,7 @@ class List(TinyWidget):
                 self.data_dict[item['id']] = item.copy()
 
             self.ids = ids
-            
+
         self.values = copy.deepcopy(data)
         self.headers, self.hiddens, self.data, self.field_total, self.buttons = self.parse(root, fields, data)
 
@@ -186,7 +195,7 @@ class List(TinyWidget):
         self.columns += (self.buttons or 0) and 1
 
         if self.pageable:
-            self.pager = Pager(ids=self.ids, offset=self.offset, limit=self.limit, count=self.count)
+            self.pager = Pager(ids=self.ids, offset=self.offset, limit=self.limit, count=self.count, def_limit=self.attr_limit)
             self.pager._name = self.name
 
         # make editors
@@ -211,7 +220,7 @@ class List(TinyWidget):
                 self.editors[f] = form.Hidden(**fa)
 
         # limit the data
-        if self.pageable and len(self.data) > self.limit:
+        if self.pageable and len(self.data) > self.limit and self.limit != -1:
             self.data = self.data[self.offset:]
             self.data = self.data[:min(self.limit, len(self.data))]
 
@@ -410,24 +419,40 @@ class Char(TinyWidget):
 class M2O(Char):
 
     template = """\
-        <span>
-            <a href="${link}">${text}</a>
+        <span id="${name}" class="m2o" name="${name}" ${py.attrs(value=val, relation=relation, context=ctx, domain=domain, link=link)}>
+            % if link:
+                <a href="${link}">${text}</a>
+            % else:
+                ${text}
+            % endif
         </span>
     """
+    
+    params=['relation', 'text', 'domain', 'context', 'link', 'readonly', 'val']
+    
+    def __init__(self, **attrs):        
+        super(M2O, self).__init__(**attrs)
 
     def get_text(self):
-        
+
         if isinstance(self.value, int):
             from many2one import get_name as _m2o_get_name
             self.value = self.value, _m2o_get_name(self.attrs['relation'], self.value)
             
+        self.val = self.value
         if self.value and len(self.value) > 0:
+            self.val = self.value[0]
             return self.value[-1]
 
         return ''
 
     def get_link(self):
-        return tools.url('/form/view', model=self.attrs['relation'], id=(self.value or False) and self.value[0])
+        m2o_link = int(self.attrs.get('link', 1))
+
+        if m2o_link == 1:
+            return tools.url('/form/view', model=self.attrs['relation'], id=(self.value or False) and self.value[0])
+        else:
+            return None
 
 class O2M(Char):
 
@@ -443,6 +468,10 @@ class Selection(Char):
 
     def get_text(self):
         if self.value:
+
+            if isinstance(self.value, (tuple, list)):
+                self.value = self.value[0]
+
             selection = self.attrs['selection']
             for k, v in selection:
                 if k == self.value:
@@ -467,6 +496,10 @@ class FloatTime(Char):
     def get_text(self):
         val = self.value or 0.0
         t = '%02d:%02d' % (math.floor(abs(val)),round(abs(val)%1+0.01,2) * 60)
+
+        hour, min = t.split(':')
+        if int(min) == 60:
+            t = str(int(hour) + 1) + ":00"
         if val < 0:
             t = '-' + t
 
@@ -493,9 +526,9 @@ class ProgressBar(Char):
 
     def get_text(self):
         if isinstance(self.value, float):
-            self.value = '%.2f' % (self.value)            
+            self.value = '%.2f' % (self.value)
             self.value = float(self.value)
-            
+
             if self.value > 100.0:
                 self.range = 100.0
             else:
@@ -522,7 +555,7 @@ class Boolean(Char):
             return _('No')
 
 class Button(TinyInputWidget):
-    
+
     params = ['icon', 'id', 'parent_grid', 'btype', 'confirm', 'width', 'context']
 
     template="""
