@@ -135,7 +135,13 @@ class Screen(TinyInputWidget):
             ctx = rpc.session.context.copy()
             ctx.update(self.context)
             view = cache.fields_view_get(self.model, view_id, view_type, ctx, self.hastoolbar)
-
+        
+        fields = view['fields']
+        for dom in self.domain:
+            if dom[0] in fields:
+                field_dom = str(fields[dom[0]].setdefault('domain', []))
+                fields[dom[0]]['domain'] = field_dom[:1] + str(('id', dom[1], dom[2])) + ',' + field_dom[1:]
+                
         self.add_view(view, view_type)
 
     def add_view(self, view, view_type='form'):
@@ -151,11 +157,11 @@ class Screen(TinyInputWidget):
                                     context=self.context,
                                     editable=self.editable,
                                     readonly=self.readonly,
-                                    nodefault=self.nodefault, nolinks=self.link)
+                                    nodefault=self.nodefault, nolinks=self.link, is_wizard=self.is_wizard)
 
             if not self.is_wizard and self.ids is None:
                 proxy = rpc.RPCProxy(self.model)
-                self.ids = proxy.search(self.domain, self.offset or False, self.limit or False, 0, self.context)
+                self.ids = proxy.search(self.domain, self.offset or False, self.limit or 20, 0, self.context)
                 self.count = proxy.search_count(self.domain, self.context)
 
         elif view_type == 'tree':
@@ -165,6 +171,7 @@ class Screen(TinyInputWidget):
                                         ids=self.ids,
                                         domain=self.domain,
                                         context=self.context,
+                                        view_mode=self.view_mode,
                                         editable=self.editable,
                                         selectable=self.selectable,
                                         offset=self.offset, limit=self.limit, count=self.count, nolinks=self.link)
@@ -177,11 +184,16 @@ class Screen(TinyInputWidget):
             self.widget = graph.Graph(model=self.model,
                                       view=view,
                                       view_id=view.get('view_id', False),
+                                      view_ids = self.view_ids,
                                       ids=self.ids, domain=self.domain,
                                       context=self.context)
             self.ids = self.widget.ids
 
         elif view_type == 'calendar':
+            if self.ids is None:
+                proxy = rpc.RPCProxy(self.model)
+                self.ids = proxy.search(self.domain, self.offset or False, self.limit or False, 0, self.context)
+            
             self.widget = tinycalendar.get_calendar(view=view,
                                                     model=self.model,
                                                     ids=self.ids,
